@@ -2,15 +2,17 @@
 
 __author__ = """Matthew Andres Moreno"""
 __email__ = "m.more500@gmail.com"
-__version__ = "1.0.5"
+__version__ = "1.5.0"
 
 from . import (
     _auxiliary_lib,
     genome_instrumentation,
     juxtaposition,
     phylogenetic_inference,
+    serialization,
     stratum_retention_strategy,
     stratum_retention_viz,
+    test_drive,
 )
 
 __all__ = [
@@ -18,6 +20,8 @@ __all__ = [
     "genome_instrumentation",
     "juxtaposition",
     "phylogenetic_inference",
+    "serialization",
     "stratum_retention_strategy",
     "stratum_retention_viz",
+    "test_drive",
 ]
