@@ -1,14 +1,25 @@
 from copy import copy
 import math
+import sys
 import typing
+import warnings
 
 from interval_search import binary_search
+import opytional as opyt
 
 from ..stratum_retention_strategy.stratum_retention_algorithms import (
     perfect_resolution_algo,
 )
 from ._HereditaryStratum import HereditaryStratum
 from .stratum_ordered_stores import HereditaryStratumOrderedStoreList
+from .stratum_ordered_stores._detail import HereditaryStratumOrderedStoreBase
+
+# define type alias for ordered stores
+OrderedStore = typing.Union[
+    typing.Callable[..., HereditaryStratumOrderedStoreBase],
+    typing.Tuple[HereditaryStratumOrderedStoreBase, int],
+    None,
+]
 
 
 class HereditaryStratigraphicColumn:
@@ -59,7 +70,8 @@ class HereditaryStratigraphicColumn:
         always_store_rank_in_stratum: bool = True,
         stratum_differentia_bit_width: int = 64,
         initial_stratum_annotation: typing.Optional[typing.Any] = None,
-        stratum_ordered_store_factory: typing.Callable = HereditaryStratumOrderedStoreList,
+        stratum_ordered_store: OrderedStore = None,
+        stratum_ordered_store_factory: OrderedStore = None  # deprecated
     ):
         """Initialize column to track a new line of descent.
 
@@ -82,11 +94,14 @@ class HereditaryStratigraphicColumn:
             Optional object to store as an annotation. Allows arbitrary user-
             provided to be associated with the first stratum deposition in the
             line of descent.
-        stratum_ordered_store_factory : callable, optional
-            Callable to generate a container that implements the necessary
-            interface to store strata within the column. Can be configured for
-            performance reasons, but has no semantic effect. A type that can be
-            default-constructed will suffice.
+        stratum_ordered_store: callable or tuple of store and count, optional
+            One of:
+            * callable to generate a container that implements the necessary
+            interface to store strata within the column; can be configured for
+            performance reasons, but has no semantic effect.
+            * instance of one aforementioned container along with a deposition count
+            * None, in which case a default-initialized container will be used
+        stratum_ordered_store_factory: deprecated, alias of stratum_ordered_store.
 
         Notes
         -----
@@ -96,12 +111,39 @@ class HereditaryStratigraphicColumn:
         """
         self._always_store_rank_in_stratum = always_store_rank_in_stratum
         self._stratum_differentia_bit_width = stratum_differentia_bit_width
-        self._num_strata_deposited = 0
-        self._stratum_ordered_store = stratum_ordered_store_factory()
-
         self._stratum_retention_policy = stratum_retention_policy
 
-        self.DepositStratum(annotation=initial_stratum_annotation)
+        if stratum_ordered_store_factory is not None:
+            warnings.warn(
+                """stratum_ordered_store_factory kwarg is deprecated.
+                Please use stratum_ordered_store kwarg instead.""",
+                DeprecationWarning,
+            )
+            # disallow mixed use of deprecated and replacement
+            assert stratum_ordered_store is None
+            stratum_ordered_store = stratum_ordered_store_factory
+
+        if stratum_ordered_store is None:
+            # if no hstrat ordered store is specified, we use a list
+            stratum_ordered_store = HereditaryStratumOrderedStoreList
+        if callable(stratum_ordered_store):
+            # ordered store is actually an ordered store factory
+            self._stratum_ordered_store = stratum_ordered_store()
+            self._num_strata_deposited = 0
+            self.DepositStratum(annotation=initial_stratum_annotation)
+        elif isinstance(
+            stratum_ordered_store[0], HereditaryStratumOrderedStoreBase
+        ):
+            # ordered store is already an instance of an ordered store
+            (
+                self._stratum_ordered_store,
+                self._num_strata_deposited,
+            ) = stratum_ordered_store
+        else:
+            raise ValueError(
+                """stratum_ordered_store is of invalid type; \
+            should be callable or tuple(callable instance, deposition count)"""
+            )
 
     def __eq__(
         self: "HereditaryStratigraphicColumn",
@@ -139,6 +181,26 @@ class HereditaryStratigraphicColumn:
             can_omit_deposition_rank and not self._always_store_rank_in_stratum
         )
 
+    def _CreateStratum(
+        self: "HereditaryStratigraphicColumn",
+        deposition_rank: int,
+        annotation: typing.Optional[typing.Any] = None,
+        differentia: typing.Optional[int] = None,
+    ) -> HereditaryStratum:
+        """Create a hereditary stratum with stored configuration attributes."""
+        return HereditaryStratum(
+            annotation=annotation,
+            deposition_rank=(
+                # don't store deposition rank if we know how to
+                # calcualte it from stratum's position in column
+                None
+                if self._ShouldOmitStratumDepositionRank()
+                else deposition_rank
+            ),
+            differentia_bit_width=self._stratum_differentia_bit_width,
+            differentia=differentia,
+        )
+
     def DepositStratum(
         self: "HereditaryStratigraphicColumn",
         annotation: typing.Optional[typing.Any] = None,
@@ -152,16 +214,9 @@ class HereditaryStratigraphicColumn:
             provided to be associated with this stratum deposition in the
             line of descent.
         """
-        new_stratum = HereditaryStratum(
+        new_stratum = self._CreateStratum(
+            deposition_rank=self._num_strata_deposited,
             annotation=annotation,
-            deposition_rank=(
-                # don't store deposition rank if we know how to calcualte it
-                # from stratum's position in column
-                None
-                if self._ShouldOmitStratumDepositionRank()
-                else self._num_strata_deposited
-            ),
-            differentia_bit_width=self._stratum_differentia_bit_width,
         )
         self._stratum_ordered_store.DepositStratum(
             rank=self._num_strata_deposited,
@@ -170,6 +225,55 @@ class HereditaryStratigraphicColumn:
         self._PurgeColumn()
         self._num_strata_deposited += 1
 
+    def DepositStrata(
+        self: "HereditaryStratigraphicColumn",
+        num_stratum_depositions: int,
+    ) -> None:
+        """Elapse n generations.
+
+        Parameters
+        ----------
+        num_stratum_depositions: int
+            How many generations to elapse?
+        """
+        # fallback to naive approach if IterRetainedRanks not available
+        policy = self._stratum_retention_policy
+        if policy.IterRetainedRanks is None or num_stratum_depositions <= 1:
+            for __ in range(num_stratum_depositions):
+                self.DepositStratum()
+            return
+
+        prior_deposit_count = self.GetNumStrataDeposited()
+        target_deposit_count = prior_deposit_count + num_stratum_depositions
+
+        # for python 3.7+, dictionaries are guaranteed insertion ordered
+        assert sys.version_info >= (3, 7)
+        target_retained_ranks = {
+            rank: None
+            for rank in policy.IterRetainedRanks(target_deposit_count)
+        }
+
+        # delete no-longer-needed ranks
+        self._stratum_ordered_store.DelRanks(
+            ranks=(
+                rank
+                for rank in self.IterRetainedRanks()
+                if rank not in target_retained_ranks
+            ),
+            get_column_index_of_rank=self.GetColumnIndexOfRank,
+        )
+
+        # add new retained ranks
+        for rank in target_retained_ranks:
+            if rank >= prior_deposit_count:
+                self._stratum_ordered_store.DepositStratum(
+                    rank=rank,
+                    stratum=self._CreateStratum(rank),
+                )
+
+        # update generation counter
+        self._num_strata_deposited += num_stratum_depositions
+
     def _PurgeColumn(self: "HereditaryStratigraphicColumn") -> None:
         """Discard stored strata according to the configured retention policy.
 
@@ -189,16 +293,38 @@ class HereditaryStratigraphicColumn:
     ) -> typing.Iterator[int]:
         """Iterate over deposition ranks of strata stored in the column.
 
-        Order of iteration should not be considered guaranteed. The store may
-        be altered during iteration without iterator invalidation, although
-        subsequent updates will not be reflected in the iterator.
+        The store may be altered during iteration without iterator
+        invalidation, although subsequent updates will not be reflected in the
+        iterator.
         """
         if self._ShouldOmitStratumDepositionRank():
-            for idx in range(self.GetNumStrataRetained()):
-                yield self.GetRankAtColumnIndex(idx)
+            if hasattr(self._stratum_retention_policy, "IterRetainedRanks"):
+                yield from self._stratum_retention_policy.IterRetainedRanks(
+                    self.GetNumStrataDeposited()
+                )
+            else:
+                for idx in range(self.GetNumStrataRetained()):
+                    yield self.GetRankAtColumnIndex(idx)
         else:
             yield from self._stratum_ordered_store.IterRetainedRanks()
 
+    def IterRetainedStrata(
+        self: "HereditaryStratigraphicColumn",
+    ) -> typing.Iterator[HereditaryStratum]:
+        """Iterate over strata stored in the column.
+        Strata yielded from most ancient to most recent.
+        """
+        yield from self._stratum_ordered_store.IterRetainedStrata()
+
+    def HasAnyAnnotations(
+        self: "HereditaryStratigraphicColumn",
+    ) -> bool:
+        """Do any retained strata have annotations?"""
+        return any(
+            stratum.GetAnnotation() is not None
+            for stratum in self._stratum_ordered_store.IterRetainedStrata()
+        )
+
     def GetNumStrataRetained(self: "HereditaryStratigraphicColumn") -> int:
         """How many strata are currently stored within the column?
 
@@ -232,6 +358,19 @@ class HereditaryStratigraphicColumn:
             ),
         )
 
+    def GetStratumAtRank(
+        self: "HereditaryStratigraphicColumn",
+        rank: int,
+    ) -> typing.Optional[HereditaryStratum]:
+        """Get the stratum deposited at generation g.
+
+        Returns None if stratum with rank g is not retained.
+        """
+        return opyt.apply_if(
+            self.GetColumnIndexOfRank(rank),
+            self.GetStratumAtColumnIndex,
+        )
+
     def GetRankAtColumnIndex(
         self: "HereditaryStratigraphicColumn",
         index: int,
@@ -343,7 +482,7 @@ class HereditaryStratigraphicColumn:
         self: "HereditaryStratigraphicColumn",
         stratum_annotation: typing.Optional[typing.Any] = None,
     ) -> "HereditaryStratigraphicColumn":
-        """Return a cloned bundle that has had an additional stratum deposited.
+        """Return a cloned column that has had an additional stratum deposited.
 
         Does not alter self.
 
@@ -357,3 +496,20 @@ class HereditaryStratigraphicColumn:
         res = self.Clone()
         res.DepositStratum(annotation=stratum_annotation)
         return res
+
+    def CloneNthDescendant(
+        self: "HereditaryStratigraphicColumn",
+        num_stratum_depositions: int,
+    ) -> "HereditaryStratigraphicColumn":
+        """Return a cloned column that has had n additional strata deposited.
+
+        Does not alter self.
+
+        Parameters
+        ----------
+        num_stratum_depositions: int
+            How many generations should clone column be descended?
+        """
+        res = self.Clone()
+        res.DepositStrata(num_stratum_depositions)
+        return res
