@@ -10,11 +10,18 @@ from ._HereditaryStratumOrderedStoreTree import (
     HereditaryStratumOrderedStoreTree,
 )
 
+provided_stratum_ordered_stores = [
+    HereditaryStratumOrderedStoreDict,
+    HereditaryStratumOrderedStoreList,
+    HereditaryStratumOrderedStoreTree,
+]
+
 # adapted from https://stackoverflow.com/a/31079085
 __all__ = [
     "HereditaryStratumOrderedStoreDict",
     "HereditaryStratumOrderedStoreList",
     "HereditaryStratumOrderedStoreTree",
+    "provided_stratum_ordered_stores",
 ]
 
 from ..._auxiliary_lib import launder_impl_modules as _launder
