@@ -3,5 +3,7 @@
 from ..genome_instrumentation import *  # noqa: F401
 from ..juxtaposition import *  # noqa: F401
 from ..phylogenetic_inference import *  # noqa: F401
+from ..serialization import *  # noqa: F401
 from ..stratum_retention_strategy import *  # noqa: F401
 from ..stratum_retention_viz import *  # noqa: F401
+from ..test_drive import *  # noqa: F401
