@@ -18,6 +18,19 @@ from . import (
 )
 from ._detail import UnsatisfiableParameterizationRequestError
 
+provided_stratum_retention_algorithms = [
+    depth_proportional_resolution_algo,
+    depth_proportional_resolution_tapered_algo,
+    fixed_resolution_algo,
+    geom_seq_nth_root_algo,
+    geom_seq_nth_root_tapered_algo,
+    nominal_resolution_algo,
+    perfect_resolution_algo,
+    pseudostochastic_algo,
+    recency_proportional_resolution_algo,
+    stochastic_algo,
+]
+
 # adapted from https://stackoverflow.com/a/31079085
 __all__ = [
     "UnsatisfiableParameterizationRequestError",
@@ -28,6 +41,7 @@ __all__ = [
     "geom_seq_nth_root_tapered_algo",
     "nominal_resolution_algo",
     "perfect_resolution_algo",
+    "provided_stratum_retention_algorithms",
     "pseudostochastic_algo",
     "recency_proportional_resolution_algo",
     "stochastic_algo",
