@@ -4,5 +4,6 @@ import random
 def decide_if_discard(
     stratum_rank: int,
     num_stratum_depositions_completed: int,
+    retention_probability: float,
 ) -> bool:
-    return random.choice([True, False])
+    return not (random.random() < retention_probability)
