@@ -1,7 +1,8 @@
 """Visualizations for stratum retention policies."""
 
-from . import animate, plot
+from . import animate, ascii, plot
 from .animate import *  # noqa: F401
+from .ascii import *  # noqa: F401
 from .plot import *  # noqa: F401
 
-__all__ = animate.__all__ + plot.__all__
+__all__ = animate.__all__ + ascii.__all__ + plot.__all__
